<?php

namespace Drupal\jsonapi_section_components\Plugin\Block;

use Drupal\layout_builder\SectionComponent;
use Drupal\Core\Entity\EntityBase;

/**
 * Interface for blocks that process section components.
 *
 * @package Drupal\jsonapi_section_components\Plugin\Block
 */
interface SectionComponentBlockInterface {

  /**
   * Processes the section component and returns the configuration.
   *
   * @param \Drupal\layout_builder\SectionComponent $section_component
   *   The section component to process.
   *
   * @return array
   *   The processed configuration.
   */
  public function processSectionComponent(SectionComponent $section_component): array;

  /**
   * Returns the response entity for the section component.
   *
   * @param \Drupal\layout_builder\SectionComponent $section_component
   *   The section component.
   * @param \Drupal\Core\Entity\EntityBase $content
   *   The content entity.
   *
   * @return \Drupal\Core\Entity\EntityBase
   *   The response entity.
   */
  public function getResponseEntity(SectionComponent $section_component, EntityBase $content): EntityBase;
}
